@@ -8,7 +8,7 @@ from decimal import Decimal
 
 import trytond.tests.test_tryton
 from trytond.tests.test_tryton import ModuleTestCase, with_transaction
-from trytond.tests.test_tryton import doctest_setup, doctest_teardown
+from trytond.tests.test_tryton import doctest_teardown
 from trytond.tests.test_tryton import doctest_checker
 from trytond.transaction import Transaction
 from trytond.pool import Pool
@@ -112,6 +112,7 @@ class StockLotTestCase(ModuleTestCase):
                     (storage.id, product.id, None): 3,
                     })
             with Transaction().set_context(locations=[storage.id]):
+                lot1, lot2 = Lot.browse([lot1, lot2])
                 self.assertEqual(lot1.quantity, 5)
                 self.assertEqual(lot2.quantity, 8)
 
@@ -228,7 +229,7 @@ def suite():
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
             StockLotTestCase))
     suite.addTests(doctest.DocFileSuite('scenario_stock_lot_shipment_out.rst',
-        setUp=doctest_setup, tearDown=doctest_teardown, encoding='utf-8',
+            tearDown=doctest_teardown, encoding='utf-8',
             checker=doctest_checker,
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     return suite
